@@ -8,6 +8,7 @@ import re
 import shlex
 import string
 import sys
+import uuid
 import warnings
 from fnmatch import fnmatchcase
 from subprocess import list2cmdline
@@ -15,7 +16,6 @@ from subprocess import list2cmdline
 import pkg_resources
 import pluggy
 import py
-from packaging.version import parse
 
 import tox
 from tox.interpreters import Interpreters
@@ -190,7 +190,7 @@ class PosargsOption:
 class InstallcmdOption:
     name = "install_command"
     type = "argv"
-    default = "pip install {opts} {packages}"
+    default = "python -m pip install {opts} {packages}"
     help = "install command for dependencies and package under test."
 
     def postprocess(self, testenv_config, value):
@@ -390,6 +390,12 @@ def tox_addoption(parser):
         dest="sdistonly",
         help="only perform the sdist packaging activity.",
     )
+    parser.add_argument(
+        "--parallel--safe-build",
+        action="store_true",
+        dest="parallel_safe_build",
+        help="ensure two tox builds can run in parallel",
+    )
     parser.add_argument(
         "--installpkg",
         action="store",
@@ -513,8 +519,11 @@ def tox_addoption(parser):
         set.
         """
         for factor in testenv_config.factors:
-            if factor in tox.PYTHON.DEFAULT_FACTORS:
-                default = tox.PYTHON.DEFAULT_FACTORS[factor]
+            match = tox.PYTHON.PY_FACTORS_RE.match(factor)
+            if match:
+                base_exe = tox.PYTHON.PY_FACTORS_MAP[match.group(1)]
+                version = ".".join(match.group(2) or "")
+                default = "{}{}".format(base_exe, version)
 
                 if value is None or testenv_config.config.ignore_basepython_conflict:
                     return default
@@ -720,7 +729,7 @@ def tox_addoption(parser):
     parser.add_testenv_attribute(
         name="list_dependencies_command",
         type="argv",
-        default="pip freeze",
+        default="python -m pip freeze",
         help="list dependencies for a virtual environment",
     )
 
@@ -861,7 +870,7 @@ def make_hashseed():
 
 
 class parseini:
-    def __init__(self, config, inipath):
+    def __init__(self, config, inipath):  # noqa
         config.toxinipath = inipath
         config.toxinidir = config.toxinipath.dirpath()
 
@@ -898,14 +907,17 @@ class parseini:
         # prevent parsing of tox.ini this must be the first thing checked.
         config.minversion = reader.getstring("minversion", None)
         if config.minversion:
-            tox_version = parse(tox.__version__)
-            config_min_version = parse(self.config.minversion)
+            tox_version = pkg_resources.parse_version(tox.__version__)
+            config_min_version = pkg_resources.parse_version(self.config.minversion)
             if config_min_version > tox_version:
                 raise tox.exception.MinVersionError(
                     "tox version is {}, required is at least {}".format(
                         tox.__version__, self.config.minversion
                     )
                 )
+
+        self.ensure_requires_satisfied(reader.getlist("requires"))
+
         if config.option.workdir is None:
             config.toxworkdir = reader.getpath("toxworkdir", "{toxinidir}/.tox")
         else:
@@ -944,22 +956,26 @@ class parseini:
         if override:
             for name in config.indexserver:
                 config.indexserver[name] = IndexServerConfig(name, override)
+        unique_id = str(uuid.uuid4())
 
         reader.addsubstitutions(toxworkdir=config.toxworkdir)
         config.distdir = reader.getpath("distdir", "{toxworkdir}/dist")
+        self._make_thread_safe_path(config, "distdir", unique_id)
+
         reader.addsubstitutions(distdir=config.distdir)
         config.distshare = reader.getpath("distshare", distshare_default)
+        self._make_thread_safe_path(config, "distshare", unique_id)
         reader.addsubstitutions(distshare=config.distshare)
         config.sdistsrc = reader.getpath("sdistsrc", None)
         config.setupdir = reader.getpath("setupdir", "{toxinidir}")
         config.logdir = config.toxworkdir.join("log")
+        self._make_thread_safe_path(config, "logdir", unique_id)
 
         config.envlist, all_envs = self._getenvdata(reader)
 
         # factors used in config or predefined
         known_factors = self._list_section_factors("testenv")
-        known_factors.update(tox.PYTHON.DEFAULT_FACTORS)
-        known_factors.add("python")
+        known_factors.update({"py", "python"})
 
         # factors stated in config envlist
         stated_envlist = reader.getstring("envlist", replace=False)
@@ -971,7 +987,13 @@ class parseini:
         for name in all_envs:
             section = testenvprefix + name
             factors = set(name.split("-"))
-            if section in self._cfg or factors <= known_factors:
+            if (
+                section in self._cfg
+                or factors <= known_factors
+                or all(
+                    tox.PYTHON.PY_FACTORS_RE.match(factor) for factor in factors - known_factors
+                )
+            ):
                 config.envconfigs[name] = self.make_envconfig(name, section, reader._subs, config)
 
         all_develop = all(
@@ -981,6 +1003,28 @@ class parseini:
 
         config.skipsdist = reader.getbool("skipsdist", all_develop)
 
+    def _make_thread_safe_path(self, config, attr, unique_id):
+        if config.option.parallel_safe_build:
+            path = getattr(config, attr)
+            value = py.path.local(path.dirname).join("{}-{}".format(path.basename, unique_id))
+            setattr(config, attr, value)
+
+    @staticmethod
+    def ensure_requires_satisfied(specified):
+        fail = False
+        for s in specified:
+            try:
+                pkg_resources.get_distribution(s)
+            except pkg_resources.RequirementParseError:
+                raise
+            except Exception:
+                fail = True
+                print(
+                    "requirement missing {}".format(pkg_resources.Requirement(s)), file=sys.stderr
+                )
+        if fail:
+            raise RuntimeError("not all requirements satisfied, install them alongside tox")
+
     def _list_section_factors(self, section):
         factors = set()
         if section in self._cfg:
@@ -1219,7 +1263,7 @@ class SectionReader:
         else:
             x = self._apply_factors(x)
 
-        if replace and x and hasattr(x, 'replace'):
+        if replace and x and hasattr(x, "replace"):
             x = self._replace(x, name=name, crossonly=crossonly)
         # print "getstring", self.section_name, name, "returned", repr(x)
         return x
